@@ -92,9 +92,18 @@ ALLOWED_LIBRARY_FILE_EXTENSIONS = [".py"]
 
 ROBOT_FILE_EXTENSION = ".robot"
 RESOURCE_FILE_EXTENSION = ".resource"
+REST_EXTENSIONS = {".rst", ".rest"}
+JSON_EXTENSIONS = {".json", ".rsrc"}
 
-ALLOWED_RESOURCE_FILE_EXTENSIONS = [ROBOT_FILE_EXTENSION, RESOURCE_FILE_EXTENSION]
-ALLOWED_VARIABLES_FILE_EXTENSIONS = [".py", ".yml", ".yaml"]
+ALLOWED_RESOURCE_FILE_EXTENSIONS = (
+    {ROBOT_FILE_EXTENSION, RESOURCE_FILE_EXTENSION, *REST_EXTENSIONS, *JSON_EXTENSIONS}
+    if get_robot_version() >= (6, 1)
+    else {ROBOT_FILE_EXTENSION, RESOURCE_FILE_EXTENSION, *REST_EXTENSIONS}
+)
+
+ALLOWED_VARIABLES_FILE_EXTENSIONS = (
+    {".py", ".yml", ".yaml", ".json"} if get_robot_version() >= (6, 1) else {".py", ".yml", ".yaml"}
+)
 ROBOT_DOC_FORMAT = "ROBOT"
 REST_DOC_FORMAT = "REST"
 
@@ -387,7 +396,7 @@ class KeywordDoc(SourceEntity):
 
     @single_call
     def is_private(self) -> bool:
-        if get_robot_version() < (6, 0, 0):
+        if get_robot_version() < (6, 0):
             return False
 
         return "robot:private" in self.normalized_tags()
@@ -819,6 +828,8 @@ def is_library_by_path(path: str) -> bool:
 
 
 def is_variables_by_path(path: str) -> bool:
+    if get_robot_version() >= (6, 1):
+        return path.lower().endswith((".py", ".yml", ".yaml", ".json", "/", os.sep))
     return path.lower().endswith((".py", ".yml", ".yaml", "/", os.sep))
 
 
@@ -888,11 +899,11 @@ class KeywordWrapper:
     @property
     def source(self) -> Any:
         try:
-            return self.kw.source
+            return str(self.kw.source) if self.kw.source is not None else self.source
         except (SystemExit, KeyboardInterrupt):
             raise
         except BaseException:
-            return self.lib_source
+            return str(self.lib_source) if self.lib_source is not None else self.lib_source
 
     @property
     def lineno(self) -> Any:
@@ -1085,6 +1096,8 @@ def resolve_variable(
     _update_env(working_dir)
 
     robot_variables = resolve_robot_variables(working_dir, base_dir, command_line_variables, variables)
+    if get_robot_version() >= (6, 1):
+        return VariableFinder(robot_variables).find(name.replace("\\", "\\\\"))
 
     return VariableFinder(robot_variables.store).find(name.replace("\\", "\\\\"))
 
@@ -1518,6 +1531,9 @@ def get_variables_doc(
     from robot.utils.importer import Importer
     from robot.variables.filesetter import PythonImporter, YamlImporter
 
+    if get_robot_version() >= (6, 1):
+        from robot.variables.filesetter import JsonImporter
+
     import_name: str = name
     stem = Path(name).stem
     module_spec: Optional[ModuleSpec] = None
@@ -1530,6 +1546,9 @@ def get_variables_doc(
             if import_name.lower().endswith((".yaml", ".yml")):
                 source = import_name
                 importer = YamlImporter()
+            elif get_robot_version() >= (6, 1) and import_name.lower().endswith(".json"):
+                source = import_name
+                importer = JsonImporter()
             else:
                 if not is_variables_by_path(import_name):
                     module_spec = get_module_spec(import_name)
@@ -1890,6 +1909,7 @@ def iter_variables_from_python_path(
                             if allow_modules and f.suffix.lower() not in [
                                 ".yaml",
                                 ".yml",
+                                *[".json" if get_robot_version() >= (6, 1) else []],
                             ]:
                                 yield CompleteResult(f.stem, CompleteResultKind.VARIABLES_MODULE)
                             if allow_files:
